@@ -20,7 +20,10 @@ inline static prefix_t* make_prefix(int family, inx_addr * addr, unsigned int wi
     if ( family == AF_INET6 && width > 128 )
         return 0;
 
-    prefix_t* subnet = new prefix_t;
+    prefix_t* subnet = (prefix_t*) malloc(sizeof(prefix_t));
+
+	if ( ! subnet )
+		return 0;
 
     if ( family == AF_INET )
         memcpy(&subnet->add.sin, addr, sizeof(subnet->add.sin));
@@ -85,6 +88,11 @@ inline static bool parse_cidr(const char *cidr, int *family, inx_addr *subnet, u
     return true;
 }
 
+static void free_data(void *data)
+{
+    Py_DECREF(static_cast<PyObject*>(data));
+}
+
 SubnetTree::SubnetTree(bool arg_binary_lookup_mode)
 {
     tree = New_Patricia(128);
@@ -93,7 +101,7 @@ SubnetTree::SubnetTree(bool arg_binary_lookup_mode)
 
 SubnetTree::~SubnetTree()
 {
-    Destroy_Patricia(tree, 0);
+    Destroy_Patricia(tree, (void (*)())free_data);
 }
 
 PyObject* SubnetTree::insert(const char *cidr, PyObject* data)
